@@ -58,8 +58,11 @@ struct menu_info_t_ {
 struct settings_t_ {
     int volume_max;
     int volume_inc;
+    gboolean reverse_scroll;
     gboolean icon_tooltip;
     gboolean monitors;
+    // Grab volume control keys
+    gboolean key_grabbing;
     // Notification options below
     gboolean n_new;
     gboolean n_sink;
@@ -127,10 +130,12 @@ menu_info_item_t* menu_info_item_get(menu_info_t* mi, uint32_t index);
 menu_info_item_t* menu_info_item_get_by_name(menu_info_t* mi, const char* name);
 menu_info_item_t* menu_info_item_get_by_desc(menu_info_t* mi, const char* desc);
 
+void menu_info_item_activated(GtkWidget* item, menu_info_item_t* mii);
 void menu_info_item_clicked(GtkWidget* item, GdkEventButton* event,
         menu_info_item_t* mii);
 void menu_info_item_scrolled(GtkWidget* item, GdkEventScroll* event,
         menu_info_item_t* mii);
+void menu_info_subitem_activated(GtkWidget* item, menu_info_item_t* mii);
 void menu_info_subitem_clicked(GtkWidget* item, GdkEventButton* event,
         menu_info_item_t* mii);
 
